@@ -8,7 +8,7 @@
  */
 
 #include "discoverwidget.h"
-#include "debug_p.h"
+#include "bluedevil_sendfile.h"
 
 #include <QAction>
 #include <QIcon>
@@ -39,12 +39,11 @@ public:
     BluezQt::DevicePtr device(const QModelIndex &index) const;
 
 private:
-    BluezQt::DevicesModel *m_devicesModel;
+    BluezQt::DevicesModel *m_devicesModel = nullptr;
 };
 
 DevicesProxyModel::DevicesProxyModel(QObject *parent)
     : QSortFilterProxyModel(parent)
-    , m_devicesModel(nullptr)
 {
     setDynamicSortFilter(true);
     sort(0, Qt::DescendingOrder);
@@ -153,3 +152,5 @@ void DiscoverWidget::fixAdaptersError()
         adapter->setPowered(true);
     }
 }
+
+#include "moc_discoverwidget.cpp"
